function bool = incompatible(A,B)

% BOOL = incompatible(A,B)
%
% Determines whether timescale objects A and B are compatible. Compatible timescales
% have the same number of intervals, with each interval of the same type (continuous
% or discrete) and holding the same number of data points. BOOL can have the following
% values:
%   0   The timescales are compatible.
%   1   The timescales have a differing number of intervals.
%   2   The timescales have differing interval types.
%   3   At least one interval in A has a different number of data points than
%       its companion in B.
%   4   A or B is not a timescale object.

% Ian Gravagne, 12/30/03 Baylor University


if(~isa(A,'timescale') | ~isa(B,'timescale'))
    bool = 4; return;
elseif(size(A.type,2) ~= size(B.type,2))
    bool = 1; return;
elseif(sum(A.type(2,:) ~= B.type(2,:)))
    bool = 2; return;
elseif(sum(A.type(1,:) ~= B.type(1,:)))
    bool = 3; return;
else
    bool = 0;
end

